@@ -6,14 +6,14 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class GnomeProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__("GNOME", ProfileType.DesktopEnv)
+		super().__init__('GNOME', ProfileType.DesktopEnv)
 
 	@property
 	@override
 	def packages(self) -> list[str]:
 		return [
-			"gnome",
-			"gnome-tweaks",
+			'gnome',
+			'gnome-tweaks',
 		]
 
 	@property
